@@ -47,6 +47,10 @@ import           Location hiding (unLoc)
 import           Util (convertDosLineEndings)
 import           PackageDBs (getPackageDBArgs)
 
+#if __GLASGOW_HASKELL__ >= 806
+import           DynamicLoading (initializePlugins)
+#endif
+
 -- | A wrapper around `SomeException`, to allow for a custom `Show` instance.
 newtype ExtractError = ExtractError SomeException
   deriving Typeable
@@ -107,16 +111,18 @@ parse args = withGhc args $ \modules_ -> withTempOutputDir $ do
   mods' <- if needsTemplateHaskellOrQQ mods then enableCompilation mods else return mods
 
   let sortedMods = flattenSCCs (topSortModuleGraph False mods' Nothing)
-  reverse <$> mapM (parseModule >=> typecheckModule >=> loadModule) sortedMods
+  reverse <$> mapM (loadModPlugins >=> parseModule >=> typecheckModule >=> loadModule) sortedMods
   where
     -- copied from Haddock/Interface.hs
     enableCompilation :: ModuleGraph -> Ghc ModuleGraph
     enableCompilation modGraph = do
 #if __GLASGOW_HASKELL__ < 707
       let enableComp d = d { hscTarget = defaultObjectTarget }
-#else
+#elif __GLASGOW_HASKELL__ < 809
       let enableComp d = let platform = targetPlatform d
                          in d { hscTarget = defaultObjectTarget platform }
+#else
+      let enableComp d = d { hscTarget = defaultObjectTarget d }
 #endif
       modifySessionDynFlags enableComp
       -- We need to update the DynFlags of the ModSummaries as well.
@@ -162,6 +168,16 @@ parse args = withGhc args $ \modules_ -> withTempOutputDir $ do
       , includePaths = addQuoteInclude (includePaths d) [f]
       }
 
+#if __GLASGOW_HASKELL__ >= 806
+    -- Since GHC 8.6, plugins are initialized on a per module basis
+    loadModPlugins modsum = do
+      hsc_env <- getSession
+      dynflags' <- liftIO (initializePlugins hsc_env (GHC.ms_hspp_opts modsum))
+      return $ modsum { ms_hspp_opts = dynflags' }
+#else
+    loadModPlugins = return
+#endif
+
 -- | Extract all docstrings from given list of files/modules.
 --
 -- This includes the docstrings of all local modules that are imported from
